pub fn init(kernel_root_page: VirtAddr)Expand description
Map the heap virtual address range to physical frames and initialize the allocator.
Panics
Panics with PanicCode::OutOfMemory if the PMM cannot satisfy any frame allocation.
pub fn init(kernel_root_page: VirtAddr)Map the heap virtual address range to physical frames and initialize the allocator.
Panics with PanicCode::OutOfMemory if the PMM cannot satisfy any frame allocation.